Documentation
¶
Overview ¶
Package progress provides progress bar components for cbwsh.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bar ¶
type Bar struct {
// contains filtered or unexported fields
}
Bar represents a progress bar component.
func NewBarWithColors ¶
NewBarWithColors creates a new progress bar with custom colors.
func (*Bar) IncrementBy ¶
IncrementBy increments progress by a specific amount.
func (*Bar) IsFinished ¶
IsFinished returns whether the progress is complete.
func (*Bar) SetMessage ¶
SetMessage sets the progress message.
type Model ¶
type Model struct {
Bar *Bar
// contains filtered or unexported fields
}
Model is a bubbletea model for a progress bar.
type MultiBar ¶
type MultiBar struct {
// contains filtered or unexported fields
}
MultiBar manages multiple progress bars.
func NewMultiBar ¶
func NewMultiBar() *MultiBar
NewMultiBar creates a new multi-bar progress tracker.
func (*MultiBar) AllFinished ¶
AllFinished returns whether all bars are finished.
type Spinner ¶
type Spinner struct {
// contains filtered or unexported fields
}
Spinner represents a spinner component.
func (*Spinner) SetMessage ¶
SetMessage sets the spinner message.
Click to show internal directories.
Click to hide internal directories.